package ws

import (
	"time"

	"git.paulbsd.com/paulbsd/ipbl/src/config"
	"git.paulbsd.com/paulbsd/ipbl/src/models"
	"golang.org/x/net/websocket"
)

var WebSocketChannel = make(chan models.APIEvent, 100)
var WebSocketChannelDone = make(chan bool)

var LISTENERS map[string]*ConnectionInfo

func Init(cfg *config.Config) {
	LISTENERS = make(map[string]*ConnectionInfo)
}

func WelcomeAgents(ws *websocket.Conn, welcome WSWelcome, t string) {
	connectinfo, ok := LISTENERS[welcome.Hostname]

	if !ok {
		switch t {
		case "ps":
			connectinfo := ConnectionInfo{
				ConnectionPS: ws,
				InitDate:     time.Now(),
			}
			LISTENERS[welcome.Hostname] = &connectinfo
		case "rr":
			connectinfo := ConnectionInfo{
				ConnectionRR: ws,
				InitDate:     time.Now(),
			}
			LISTENERS[welcome.Hostname] = &connectinfo
		}
	} else {
		switch t {
		case "ps":
			connectinfo.ConnectionPS = ws
		case "rr":
			connectinfo.ConnectionRR = ws
		}
	}
}

func gcConnOnError(ws *websocket.Conn) (err error) {
	for index, value := range LISTENERS {
		if value.ConnectionPS == ws || value.ConnectionRR == ws {
			value.ConnectionPS.Close()
			value.ConnectionRR.Close()
			delete(LISTENERS, index)
		}
	}
	return err
}

type ConnectionInfo struct {
	ConnectionPS *websocket.Conn
	ConnectionRR *websocket.Conn
	InitDate     time.Time
}

type WSWelcome struct {
	Hostname string
}
